#!/bin/bash

NV_PATH="/var/data/reports/scripts"
OLD_SEASONAL_FILES="/var/data/reports/scripts/spreader_data"
NEW_SEASONAL_FILES="/var/data/reports/scripts/seasonal_totals/spreader_data"
TMP_SEASONAL_FILES="/tmp/spreader_data"
SEASONAL_DIR="/var/data/reports/scripts/seasonal_totals"
SPREADER_PCYP_STRING=1000

USERSTRING=$1

main () {
	echo "*** Started Unininstall Script ***"
	checkReset
	removeOldSpreaderFiles
	echo "*** Completed Uninstall Script ***"
}


# Function that removes all spreader files but not seasonal_total files 
removeOldSpreaderFiles () {
	echo " Removing Old Spreader Files"
	rm -rf $NV_PATH/report51.sh
	rm -rf $NV_PATH/report52.sh
	rm -rf $NV_PATH/report1020.sh
	rm -rf $NV_PATH/report1021.sh
	rm -rf $NV_PATH/report20.sh
	rm -rf $NV_PATH/uninstall_cirus.sh
	rm -rf $NV_PATH/uninstall_epoke.sh
	rm -rf $NV_PATH/uninstall_cs550.sh
	rm -rf $NV_PATH/uninstall.sh
	rm -rf $NV_PATH/report1026.sh
	rm -rf $NV_PATH/spreader.py
	rm -rf $NV_PATH/report100.sh
	rm -rf $NV_PATH/config
	rm -rf $NV_PATH/controller
}

checkReset (){
#Check If Reset is required
	if [[ $USERSTRING == "KEEP" ]]; then 
		echo " Checking for Previous Seasonal Total Files"
		checkNewSeasonals
		resetConfig
		return
	elif [[ $USERSTRING == "RESET" ]]; then
		echo " Removing Seasonal Total Files; New Files will be created at next Boot up or during configApp.sh"
		removeSeasonalTotals
		resetConfig
		return
	elif [[ $USERSTRING == "UNINSTALL" ]]; then
		echo " Uninstalling Spreaders"
		resetConfig
		removeSeasonalTotals
		rm -rf /var/data/reports/scripts/seasonal_totals/*
	else
		echo " ERROR - User input = $USERSTRING, should be RESET/KEEP/UNINSTALL"
		exit 1
	fi
}

copyOldSeasonalTotals () {
	if [[ ! -d "$SEASONAL_DIR" ]]; then
		echo " Creating Seasonal Total Directory"
		mkdir $SEASONAL_DIR
	fi
	
	echo " Copying Old Seasonal Total Files"
	cp -p $TMP_SEASONAL_FILES* $SEASONAL_DIR/
	echo " Removing Old Seasonal Total Files"
	rm -rf $OLD_SEASONAL_FILES*
	echo " Success: Previous seasonal total files moved to new directory"
}

checkOldSeasonals () {
	if [[ -e "$OLD_SEASONAL_FILES.txt" ]] && [[ -e "$OLD_SEASONAL_FILES.crc" ]]; then
		copyOldSeasonalTotals
		return 
	else
		echo " No Seasonal Total Files, Will be created at next boot up or during configApp.sh"
		return 
	fi
}

checkNewSeasonals () {
	echo " Checking For New Seasonal Total Files"
	if [[ -e "$NEW_SEASONAL_FILES.txt" ]] && [[ -e "$NEW_SEASONAL_FILES.crc" ]]; then
		echo " Seasonal Total Files Already Exist"
		return
	else
		echo " Checking for Old Seasonal Total Files"
		checkOldSeasonals
		return
	fi
}

removeSeasonalTotals () {
	rm -rf $OLD_SEASONAL_FILES*
	rm -rf $SEASONAL_DIR
}

resetConfig () {
	echo " Removing old Spreader Config Values"
	cmd mode 2
	cmd port 1 115200 8 n 1 0
	
	cmd vcccond 8 0
	cmd vccreport 8 0
	
	cmd aux dev AUX1

	cmd igncond 7 0
	cmd ignreport 7 0
	cmd igncond 8 0
	cmd ignreport 8 0
	
	cmd reptype 51 0 0 0 0 0
	cmd reptype 52 0 0 0 0 0
	cmd reptype 8 0 0 0 0 0
	

	if /usr/bin/cmd gpsaddmes | grep "1000"; then
		VALUE=$(cmd gpsaddmes | grep 1000 | awk -F " " '{print$3}')
		for i in $VALUE; do
			cmd gpsdelmes "$i" 1000
			echo "  Removed PCYP Msg 1000 from gpsaddmes $i"
		done
	fi

	if /usr/bin/cmd gpsaddmes | grep "1500"; then
		VALUE=$(cmd gpsaddmes | grep 1500 | awk -F " " '{print$3}')
		for i in $VALUE; do
			cmd gpsdelmes "$i" 1500
			echo "  Removed PCYP Msg 1500 from gpsaddmes $i"
		done
	fi
	
	if /usr/bin/cmd pcyp msg query | grep "1000:"; then
		cmd pcyp msg del 1000
	fi
	if /usr/bin/cmd pcyp msg query | grep "1500:"; then
		cmd pcyp msg del 1500
	fi
	return
}

main