#!/bin/bash
# Must link to vccreport 8
# Start/Monitor Script
#   Based on defined app, monitor scripts to make sure they are always running
# Single shot script, gets called again on vcccond approx every 30 seconds

INSTALL_DIR="/var/data/reports/scripts"
CRC_FILE="/tmp/spreader_data.crc"
DATA_FILE="/tmp/spreader_data.txt"
CRC_APP="/tmp/fix_crc.py"
SEASONAL_FILES="/var/data/reports/scripts/seasonal_totals"

runSpreaders () {
	# This runs the functions required based on the App that is selected.
	# based on config, run correct spreader.
	CHECKMODE=$(cmd mode | grep "cmd mode" | awk -F " " '{print$3}')

	if [[ $CHECKMODE == "0" ]]; then
		checkRunCirus
		return
	elif [[ $CHECKMODE == "23" ]]; then
		loadNVData
		checkRunCS550
		updateBackupTMP
		updateBackupNV
		backupNVData
		return
	elif [[ $CHECKMODE == "24" ]]; then
		loadNVData
		checkRunEpoke
		updateBackupTMP
		updateBackupNV
		backupNVData
		return
	else
		return
	fi
}

updateBackupNV () {
	if [ -e /tmp/primaryNVBackupComplete ]; then
		NVMAIN=$(cat /var/data/reports/scripts/seasonal_totals/spreader_data.txt)
		NVBACKUP=$(cat /var/data/reports/scripts/seasonal_totals/spreader_data.bak.txt)
		if [[ "$NVMAIN" != "$NVBACKUP" ]]; then
		#Copy Primary NV to Backup NV
			cp $INSTALL_DIR/seasonal_totals/spreader_data.crc $INSTALL_DIR/seasonal_totals/spreader_data.bak.crc
			cp $INSTALL_DIR/seasonal_totals/spreader_data.txt $INSTALL_DIR/seasonal_totals/spreader_data.bak.txt
			cmd event add SPREADER_SAVE_NVSEASONAL_TO_NVBACKUPSEASONAL
			rm /tmp/primaryNVBackupComplete
		fi
	fi
}

updatePrimaryNV () {
#Copies Primary data in NV with primary data from tmp IF watchCRC is successful
	watchCRC
	cp /tmp/spreader_data.txt $INSTALL_DIR/seasonal_totals/spreader_data.txt
	cp /tmp/spreader_data.crc $INSTALL_DIR/seasonal_totals/spreader_data.crc
	touch /tmp/primaryNVBackupComplete
	cmd event add SPREADER_SAVE_TMPSEASONAL_TO_NVSEASONAL
}

updateBackupTMP () {
#Copies primary data file in tmp to backup data files in tmp
	watchCRC
	cp /tmp/spreader_data.txt /tmp/spreader_data.bak.txt
	cp /tmp/spreader_data.crc /tmp/spreader_data.bak.crc
}

backupNVData () {
# This function backs up data to NV for Epoke and CS550
# Monitors IGN state, and time.
# 
# If IGN = 0 backup data once
# Else backup every 30 minutes
#
	if [ ! -e /tmp/SpreaderNVTimestamp ]
	then
		#write UTC timestamp of current time to file
		date +%s > /tmp/SpreaderNVTimestamp
		return
	else
		TIMENOW=$(date +%s)
		TIMEBEFORE=$(cat /tmp/SpreaderNVTimestamp)
		TIMEELAPSED=$(($TIMENOW - $TIMEBEFORE))
		IGNVALUE=$(cmd sysdb get VEH_IGN | grep VEH_IGN | awk -F "=" '{print$2}')
		if [ "$IGNVALUE" == 0 ]; then
			if [ $TIMEELAPSED -ge 5 ]; then
				if [ ! -e /tmp/ignitionLowBackupComplete ]; then
					updatePrimaryNV
					touch /tmp/ignitionLowBackupComplete
					date +%s > /tmp/SpreaderNVTimestamp
					logger "backupSeasonalTotals: IGN Low Detected, Data backed up"
					cmd event add SPREADER_SAVE_TO_NV_LPM
					return
				fi
			fi
		elif [ "$IGNVALUE" == 1 ]; then
		#Check IGN LOW backup flag and remove if there
			if [ -e /tmp/ignitionLowBackupComplete ]; then
				rm /tmp/ignitionLowBackupComplete
				return
			fi
		#Backup Data every 30 minutes
			if [ $TIMEELAPSED -ge 1800 ]; then
				updatePrimaryNV
				date +%s > /tmp/SpreaderNVTimestamp
				logger "backupSeasonalTotals: IGN High Detected, Data backed up after $TIMEELAPSED seconds"
				cmd event add SPREADER_SAVE_TO_NV_30MINS
				return
			fi
		fi
	fi
}

loadNVData () {
#This function makes sure that the seasonal data is moved to /tmp so that the app can update the values.
	if [ -e /tmp/spreader_data.txt ] && [ -e /tmp/spreader_data.crc ]; then
		return
	elif [ -e $INSTALL_DIR/seasonal_totals/spreader_data.txt ] && [ -e $INSTALL_DIR/seasonal_totals/spreader_data.crc ]; then
		cp $INSTALL_DIR/seasonal_totals/* /tmp/
		logger "report100: Data copied from NV to tmp"
		cmd event add SPREADER_NV_SEASONALS_LOADED
		return
	else
		.$INSTALL_DIR/config/seasonalReset.sh SendSpreaderReset
		logger "report100: No seasonal total files exist, Initializing files"
		cmd event add SEASONAL_FILES_DONT_EXIST_CREATING_FILES
		return
	fi
}

checkRunEpoke () {
# This function monitors Epoke to make sure it is running, It will run it if it is not, and kill it if theres multiple isntances
	result=`ps | grep runEpoke | grep -v grep  -c`
	if [ "$result" == 0 ]; then
		$INSTALL_DIR/controller/runEpoke.sh &
		return
   	elif [ "$result" == 1 ]; then
		return
	else
		killall -9 runEpoke.sh
		return
	fi
}

checkRunCirus () {
# This function monitors Cirus to make sure it is running, It will run it if it is not, and kill it if theres multiple isntances
	result=`ps | grep runCirus | grep -v grep -c`
	if [ "$result" == 0 ]; then
		$INSTALL_DIR/controller/runCirus.sh &
		return
   	elif [ "$result" == 1 ]; then
		return
	else
		killall -9 runCirus.sh
		return
	fi
}

checkRunCS550 () {
# This function monitors CS550 to make sure it is running, It will run it if it is not, and kill it if theres multiple isntances
	result=`ps | grep runCS550 | grep -v grep -c`
	if [ "$result" == 0 ]; then
		$INSTALL_DIR/controller/runCS550.sh &
		return
   	elif [ "$result" == 1 ]; then
		return
	else
		killall -9 runCS550.sh
		return
	fi
}

fixCRC() {
        if [ ! -f "$CRC_APP" ]; then
                echo "import os" > $CRC_APP
                echo "import sys" >> $CRC_APP
                echo "import binascii" >> $CRC_APP
                echo "TMP_DATA_FILE = '/tmp/spreader_data.txt'" >> $CRC_APP
                echo "TMP_CRC = '/tmp/spreader_data.crc'" >> $CRC_APP
                echo "buf = open(TMP_DATA_FILE, 'rb').read()" >> $CRC_APP
                echo "crc = (binascii.crc32(buf) & 0xFFFFFFFF)" >> $CRC_APP
                echo "crc_file = open(TMP_CRC, 'w')" >> $CRC_APP
                echo "crc_file.write('%08X' % crc)" >> $CRC_APP
                echo "crc_file.close()" >> $CRC_APP
        fi
        python $CRC_APP
}

watchCRC() {
        if [[ -f "$CRC_FILE" && ! -s "$CRC_FILE" ]]; then
                cmd event add ERROR_CRC_EMPTY_CHECKING_AGAIN
				sleep 1
                if [[ -f "$CRC_FILE" && ! -s "$CRC_FILE" ]]; then
					cmd event add ERROR_CRC_EMPTY_ON_SECOND_CHECK
                    if [ -f "$DATA_FILE" ]; then
						cmd event add DATA_FILE_CHECK_CRC
                        fixCRC
						cmd event add FIX_CRC_COMPLETE
                    fi
                fi
        fi
}

runSpreaders
